The ->seq_exch_abort callback only ever had one implementation,
so we can as well call it directly and drop the callback.

Signed-off-by: Hannes Reinecke <h...@suse.com>
---
 drivers/scsi/libfc/fc_exch.c | 13 ++++++++-----
 drivers/scsi/libfc/fc_fcp.c  |  4 ++--
 include/scsi/libfc.h         | 14 +-------------
 3 files changed, 11 insertions(+), 20 deletions(-)

diff --git a/drivers/scsi/libfc/fc_exch.c b/drivers/scsi/libfc/fc_exch.c
index ee34cc6..fffb9a3 100644
--- a/drivers/scsi/libfc/fc_exch.c
+++ b/drivers/scsi/libfc/fc_exch.c
@@ -629,6 +629,13 @@ static void fc_seq_set_resp(struct fc_seq *sp,
  * @ep:        The exchange to be aborted
  * @timer_msec: The period of time to wait before aborting
  *
+ * Abort an exchange and sequence. Generally called because of a
+ * exchange timeout or an abort from the upper layer.
+ *
+ * A timer_msec can be specified for abort timeout, if non-zero
+ * timer_msec value is specified then exchange resp handler
+ * will be called with timeout error if no response to abort.
+ *
  * Locking notes:  Called with exch lock held
  *
  * Return value: 0 on success else error code
@@ -692,8 +699,7 @@ static int fc_exch_abort_locked(struct fc_exch *ep,
  *
  * Return value: 0 on success else error code
  */
-static int fc_seq_exch_abort(const struct fc_seq *req_sp,
-                            unsigned int timer_msec)
+int fc_seq_exch_abort(const struct fc_seq *req_sp, unsigned int timer_msec)
 {
        struct fc_exch *ep;
        int error;
@@ -2654,9 +2660,6 @@ int fc_exch_init(struct fc_lport *lport)
        if (!lport->tt.exch_mgr_reset)
                lport->tt.exch_mgr_reset = fc_exch_mgr_reset;
 
-       if (!lport->tt.seq_exch_abort)
-               lport->tt.seq_exch_abort = fc_seq_exch_abort;
-
        if (!lport->tt.seq_assign)
                lport->tt.seq_assign = fc_seq_assign;
 
diff --git a/include/scsi/libfc.h b/include/scsi/libfc.h
index 7514cc9..50d1af1 100644
--- a/include/scsi/libfc.h
+++ b/include/scsi/libfc.h
@@ -515,19 +515,6 @@ struct libfc_function_template {
        void (*get_lesb)(struct fc_lport *, struct fc_els_lesb *lesb);
 
        /*
-        * Abort an exchange and sequence. Generally called because of a
-        * exchange timeout or an abort from the upper layer.
-        *
-        * A timer_msec can be specified for abort timeout, if non-zero
-        * timer_msec value is specified then exchange resp handler
-        * will be called with timeout error if no response to abort.
-        *
-        * STATUS: OPTIONAL
-        */
-       int (*seq_exch_abort)(const struct fc_seq *,
-                             unsigned int timer_msec);
-
-       /*
         * Indicate that an exchange/sequence tuple is complete and the memory
         * allocated for the related objects may be freed.
         *
@@ -1052,6 +1039,7 @@ struct fc_exch_mgr *fc_exch_mgr_alloc(struct fc_lport *, 
enum fc_class class,
 void fc_exch_recv(struct fc_lport *, struct fc_frame *);
 void fc_exch_mgr_reset(struct fc_lport *, u32 s_id, u32 d_id);
 int fc_seq_send(struct fc_lport *lport, struct fc_seq *sp, struct fc_frame 
*fp);
+int fc_seq_exch_abort(const struct fc_seq *, unsigned int timer_msec);
 
 /*
  * Functions for fc_functions_template
diff --git a/drivers/scsi/libfc/fc_fcp.c b/drivers/scsi/libfc/fc_fcp.c
index daad70f..2bb3f9f 100644
--- a/drivers/scsi/libfc/fc_fcp.c
+++ b/drivers/scsi/libfc/fc_fcp.c
@@ -287,9 +287,9 @@ static int fc_fcp_send_abort(struct fc_fcp_pkt *fsp)
        put_cpu();
 
        fsp->state |= FC_SRB_ABORT_PENDING;
-       rc = fsp->lp->tt.seq_exch_abort(fsp->seq_ptr, 0);
+       rc = fc_seq_exch_abort(fsp->seq_ptr, 0);
        /*
         * ->seq_exch_abort() might return -ENXIO if
         * the sequence is already completed
         */
        if (rc == -ENXIO) {
@@ -287,9 +287,9 @@ static int fc_fcp_send_abort(struct fc_fcp_pkt *fsp)
        /*
-        * ->seq_exch_abort() might return -ENXIO if
+        * fc_seq_exch_abort() might return -ENXIO if
         * the sequence is already completed
         */
-- 
1.8.5.6

--
To unsubscribe from this list: send the line "unsubscribe linux-scsi" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to